%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% This is file `icai2023.cls' (2022/10/18)
%% LaTeX document class for Proceedings of the ICAI 2023
%%
%% Copyright © 2022 Tibor Tómács
%% e-mail: tomacs.tibor@uni-eszterhazy.hu
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\NeedsTeXFormat{LaTeX2e}[1995/12/01]

\begingroup
\def\@latex@warning@no@line#1{} % For \documentclass{../icai2023}
\ProvidesClass{icai2023}[LaTeX document class for Proceedings of the ICAI 2023]
\endgroup

\LoadClass[twoside]{article}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% ERROR MESSAGE WITH XELATEX AND LUALATEX COMPILERS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{iftex}
\ifpdftex\else
  \ClassError{amiart}{Please, use pdflatex compiler}{}
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% GENERAL PACKAGES
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{cmap} % For old TeX-system
\RequirePackage{geometry}
\RequirePackage[utf8]{inputenc} % For old TeX-system
\RequirePackage[T1]{fontenc}
\RequirePackage[english]{babel}
\RequirePackage{lmodern,graphicx,xurl,xcolor,lastpage,newfile,refcount,eso-pic,tikz}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% GEOMETRY
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\geometry{
  paperwidth  = 170mm,
  paperheight = 240mm,
  width       = 126mm,
  height      = 189mm,
  headsep     =   5mm,
  top         =  28mm,
  outer       =  22mm,
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% MATH
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[intlimits]{mathtools}
\RequirePackage{amssymb,mleftright}
\mleftright

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% CAPTION
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{subcaption}
\captionsetup{
  justification=centerlast,
  font=small,
  labelfont=bf,
  labelsep=period,
  width=95mm,
  tableposition=top,
}
\captionsetup[sub]{margin=10pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% TABLE CAPTION ON THE TOP OF THE TABLE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{float}
\floatstyle{plaintop}
\restylefloat{table}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% NO INFORMATION SAVED (REDEFINED BY FINAL OPTION)
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\icai@saveinfos{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% COPYRIGHT
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\icai@copyrighttext{%
  Copyright \copyright~2023 for this paper by its authors.\\
  Use permitted under Creative Commons License
  Attribution 4.0 International (CC BY 4.0).}

\def\icai@copyright{%
  \AddToShipoutPictureBG*{%
    \begin{tikzpicture}[overlay]
      \node[anchor=north west,inner sep=0pt,outer sep=0pt] at 
      ([yshift=18mm,xshift=22mm] current page.south west)
      {\parbox{\textwidth}{% 
          \leavevmode\color{gray}% Without \leavevmode the \color puts the baseline of the \parbox[t] below
          \normalfont\scriptsize\sffamily
          \rule{\textwidth}{2pt}\\
          \icai@copyrighttext}\par};
    \end{tikzpicture}}}

%\def\icai@copyright{% If you want in footnote the copyright
%\begingroup%
%\long\def\@makefntext##1{\noindent ##1}%
%%\def\Hy@raisedlink##1{}%
%\footnotetext{\itshape\icai@copyrighttext}%
%\endgroup}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% PAGE STYLES
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\pagestyle{empty} % Without \maketitle the pagestyle is empty

\RequirePackage{fancyhdr}

%\def\icai@info{% Information in the title page
%Proceedings of the
%12\textsuperscript{th} International Conference on Applied Informatics\\
%Eger, Hungary, March ??–??, 2023}

\def\icai@info{% Information in the title page
Proceedings of the\\
12\textsuperscript{th} International Conference on Applied Informatics\\
Eger, Hungary, 2023}

\fancypagestyle{icai@titlepagestyle}{
  \fancyhf{}
  \fancyhead[L]{\parbox[t]{\textwidth}{%
      \leavevmode\color{gray}% Without \leavevmode the \color puts the baseline of the \parbox[t] below
      \normalfont\small\sffamily%
      \icai@info\\
      \rule[0.5em]{\textwidth}{2pt}}}
  \ificai@manuscript\fancyfoot[C]{\normalfont\normalsize\sffamily\color{gray}\thepage}\fi
  \def\headrulewidth{0pt}}

\fancypagestyle{icai@pagestyle}{
  \fancyhf{}
  \fancyfoot[C]{\normalfont\normalsize\sffamily\color{gray}\thepage}
  \fancyhead[L]{\normalfont\small\sffamily\color{gray} 
                Manuscript for the Proceedings of the 12\textsuperscript{th} ICAI}
  \fancyhead[R]{\normalfont\small\sffamily\color{gray}\today}
  \def\headrulewidth{0.4pt}}

\def\icai@finalpagestyle{
  \fancypagestyle{icai@pagestyle}{
  \fancyhf{}
  \fancyfoot[C]{\normalfont\normalsize\sffamily\color{gray}\thepage}
  \fancyhead[RE]{\normalfont\small\itshape\icai@authorinheadline}
  \fancyhead[RO]{\normalfont\small\itshape\icai@titleinheadline}
  \fancyhead[L]{\normalfont\small\sffamily\color{gray}ICAI 2023}
  \def\headrulewidth{0.4pt}}}

\def\icai@abstractpagestyle{
  \def\icai@info{%
    ICAI 2023\\
    12\textsuperscript{th} International Conference on Applied Informatics\\
    Eger, Hungary, 2023}
  \fancypagestyle{icai@pagestyle}{
  \fancyhf{}
  \fancyfoot[C]{\normalfont\normalsize\sffamily\color{gray}\thepage}
  \fancyhead[R]{\normalfont\small\sffamily\color{gray}Abstract}
  \fancyhead[L]{\normalfont\small\sffamily\color{gray}ICAI 2023}
  \def\headrulewidth{0.4pt}}}

\def\f@nch@warning#1{} % Turn off fancyhdr warning (icai@titlepagestyle is too high)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTIONS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newif\ificai@abstract
\newif\ificai@unproof
\newif\ificai@final
\newif\ificai@manuscript\icai@manuscripttrue
\newif\ificai@volume

\DeclareOption{abstract}{\icai@abstracttrue}
\DeclareOption{unproof}{\icai@unprooftrue\icai@manuscriptfalse}
\DeclareOption{final}{\icai@finaltrue\icai@unprooffalse\icai@manuscriptfalse}
\DeclareOption{checktoc}{\AtEndOfPackage{\icai@checktoc}}
\DeclareOption{volume}{\icai@volumetrue}

\ProcessOptions\relax

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: CHECKTOC
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\l@section{\@dottedtocline{0}{0pt}{2.3em}}

\def\icai@checktoc{%
  \ificai@manuscript\else
    \AddToHook{cmd/maketitle/before}{%
      \hypersetup{pageanchor=false}
      \thispagestyle{empty}
      \section*{Checking contents line}
      \babel@toc{english}{}\relax
      \contentsline{section}{\textsc{\icai@authorinpdfcontents},
         \icai@titleinpdfcontents}{1}{}
      \newpage
      \hypersetup{pageanchor}
      \setcounter{page}{1}
    }
  \fi}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: ABSTRACT
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ificai@abstract\icai@abstractpagestyle\fi
% See also: theorem, equation number, title format

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: UNPROOF
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ificai@unproof

\icai@finalpagestyle

\IfFileExists{linenoamsmath.sty}
  {\RequirePackage[mathlines]{linenoamsmath}
   \def\linenumberfont{\normalfont\tiny\sffamily\color{gray}}
   \linenumbers} % It turns on \allowdisplaybreaks
  {\ClassWarning{icai}{There is not linenoamsmath.sty!}}

\AddToShipoutPictureBG{%
  \begin{tikzpicture}[overlay]
    \node[rotate=48,color=black!5] at (current page.center)
    {\resizebox*{180mm}{!}{\normalfont\bfseries\sffamily UNCORRECTED PROOF}};
  \end{tikzpicture}}

\else

\allowdisplaybreaks

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: FINAL
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ificai@final

\icai@finalpagestyle

\g@addto@macro\icai@info{%
  \\pp.~\thepage--\begin{NoHyper}\pageref{LastPage}\end{NoHyper}\\
  Published at \url{http://ceur-ws.org}}

\IfFileExists{../firstpage.txt}
  {\input{../firstpage.txt}\stepcounter{page}}
  {}

\def\icai@saveinfos{
  \newoutputstream{lastpage}
  \openoutputfile{lastpage.txt}{lastpage}
  \addtostream{lastpage}{\protect\setcounter{page}{\getpagerefnumber{LastPage}}}
  \closeoutputstream{lastpage}
  \newoutputstream{htmlcontents}
  \openoutputfile{htmlcontents.txt}{htmlcontents}
  \addtostream{htmlcontents}{source: \jobname}
  \addtostream{htmlcontents}{\icai@authorinhtmlcontents}
  \addtostream{htmlcontents}{\icai@titleinhtmlcontents}
  \addtostream{htmlcontents}{\thepage–\getpagerefnumber{LastPage}}
  \closeoutputstream{htmlcontents}
  \newoutputstream{pdfcontents}
  \openoutputfile{pdfcontents.txt}{pdfcontents}
  \addtostream{pdfcontents}{\protect\VOLtocline{\jobname}{\icai@authorinpdfcontents}{\icai@titleinpdfcontents}{\thepage}}
  \closeoutputstream{pdfcontents}}

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% BIBLATEX
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{csquotes} % For biblatex package (after linenoamsmath)

\IfFileExists{ext-numeric-comp.bbx}
  {\RequirePackage[
      style       = ext-numeric-comp,
      articlein   = false,
      giveninits,
      maxbibnames = 50
    ]{biblatex}}
  {RequirePackage[maxbibnames=50]{biblatex}}

\def\bibfont{\normalfont\footnotesize}
\def\mkbibnamefamily{\scshape}
\def\mkbibnamegiven{\scshape}
\def\newunitpunct{\addcomma\addspace}
\def\finalnamedelim{\addcomma\addspace}
\def\labelnamepunct{\addcolon\addspace}
\setlength{\biblabelsep}{\labelsep}
\DeclareFieldFormat*{title}{\textit{#1}}
\DeclareFieldFormat*{booktitle}{\textnormal{#1}}
\DeclareFieldFormat*{journaltitle}{\textnormal{#1}}
\DeclareFieldFormat*{doi}{\textsc{doi}: \url{#1}}
\DeclareFieldFormat*{url}{\textsc{url}: \url{#1}}

\setcounter{biburllcpenalty}{100} % for xurl (or load xurl after biblatex) 
\setcounter{biburlucpenalty}{200} % for xurl (or load xurl after biblatex) 
\setcounter{biburlnumpenalty}{100} % for xurl (or load xurl after biblatex) 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% AUTHOR, TITLE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\author#1{\def\icai@author{#1}}
\def\icai@author{Author(s)}

\def\authorinheadline#1{\def\icai@authorinheadline{#1}}
\def\icai@authorinheadline{\icai@author}

\def\authorinhtmlcontents#1{\def\icai@authorinhtmlcontents{#1}}
\def\icai@authorinhtmlcontents{\icai@author}

\def\authorinpdfcontents#1{\def\icai@authorinpdfcontents{#1}}
\def\icai@authorinpdfcontents{\icai@author}

\def\authorinpdfmetadata#1{\def\icai@authorinpdfmetadata{#1}}
\def\icai@authorinpdfmetadata{\icai@author}

\def\title#1{\def\icai@title{#1}}
\def\icai@title{Title}

\def\titleinheadline#1{\def\icai@titleinheadline{#1}}
\def\icai@titleinheadline{\icai@title}

\def\titleinhtmlcontents#1{\def\icai@titleinhtmlcontents{#1}}
\def\icai@titleinhtmlcontents{\icai@title}

\def\titleinpdfcontents#1{\def\icai@titleinpdfcontents{#1}}
\def\icai@titleinpdfcontents{\icai@title}

\def\titleinpdfmetadata#1{\def\icai@titleinpdfmetadata{#1}}
\def\icai@titleinpdfmetadata{\icai@title}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% INSTITUTE, INST, EMAIL, THANKS, DEDICATED
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\institute#1{\def\icai@institute{\def\icai@instsep{\par\vspace{1.5mm}}#1}}
\institute{Institute(s)}

\def\icai@instsep{}
\newcounter{icai@inst}
\def\inst#1{%
  \ifhmode\unskip\fi% ignore space before \inst
  \setcounter{icai@inst}{#1}%
  \ifnum\value{icai@inst}>1\icai@instsep\fi%
  \textsuperscript{\color{gray}\normalfont\sffamily\alph{icai@inst}}%
  \ignorespaces}% ignore space after \inst

\def\thanks#1{%
  \unskip%
  \def\thefootnote{\normalfont\fnsymbol{footnote}}%
  \footnote{#1}}

\def\email#1{\href{mailto:#1}{{\def\UrlFont{\normalfont}\nolinkurl{#1}}}}

\def\dedicated#1{\def\icai@dedicated{#1}}
\def\icai@dedicated{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% KEYWORDS, AMS SUBJECT CLASSIFICATIONS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\keywords{\par\vspace{1.5mm}\noindent\textit{Keywords:}~}
\def\AMSSubjectClassification{\par\vspace{1.5mm}\noindent\textit{AMS Subject Classification:}~}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% ABSTRACT ENVIRONMENT
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewenvironment{abstract}{%
  \begin{quotation}
  \noindent\small\normalfont\textbf{Abstract.}\enskip\ignorespaces}
  {\end{quotation}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% SECTION TITLE FORMAT
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{titlesec}
\def\icai@section@fil{}
\ificai@abstract\def\icai@section@fil{\filcenter}\fi
\titleformat{\section}{\normalfont\Large\bfseries\icai@section@fil}{\thesection.}{.44em}{}
\titleformat{\subsection}{\normalfont\large\bfseries\icai@section@fil}{\thesubsection.}{.44em}{}
\titleformat{\subsubsection}{\normalfont\bfseries\icai@section@fil}{\thesubsubsection.}{.44em}{}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% EQUATION NUMBERS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ificai@abstract\else\numberwithin{equation}{section}\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% THEOREM-LIKE ENVIRONMENTS
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{amsthm}
\ificai@abstract\newtheorem{theorem}{Theorem}\else\newtheorem{theorem}{Theorem}[section]\fi
\newtheorem{lemma}[theorem]{Lemma}
\newtheorem{corollary}[theorem]{Corollary}
\theoremstyle{definition}
\newtheorem{definition}[theorem]{Definition}
\newtheorem{example}[theorem]{Example}
\newtheorem{remark}[theorem]{Remark}
\theoremstyle{plain} % Back to the default style

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% BOLDFACE PROOF
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\renewenvironment{proof}[1][\proofname]{\par
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\hskip\labelsep
        \bfseries\itshape\begin{NoHyper}%
    #1\end{NoHyper}\@addpunct{.}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% WARNING: DO NOT USE THEBIBLIOGRAPHY ENVIRONMENT!
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\@ifundefined{RenewDocumentEnvironment}{\RequirePackage{xparse}}{} % For old TeX-system
\RenewDocumentEnvironment{thebibliography}{+b}{%
  \@gobble{#1}
  \section*{References}
  {\color{red}\normalfont\sffamily\bfseries
  Please, use \texttt{references.bib} instead of \texttt{thebibliography} environment!}}
  {}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% BOLD MATH IN TITLE (BUT NOT IN \thanks)
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\AddToHook{bfseries}{\boldmath}
\AddToHook{cmd/thanks/before}{\unboldmath}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% HYPERREF
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[
  colorlinks   = true,
  bookmarks    = false,
  pdfusetitle  = false,
  pdfstartview = FitH,
  urlcolor     = blue!60!black,
  citecolor    = teal,
  linkcolor    = blue,
]{hyperref}

%\def\Hy@Warning#1{} % ???

\ificai@manuscript\else
  \AddToHook{cmd/maketitle/before}{%
    \hypersetup{
      pdftitle   = {\icai@titleinpdfmetadata},
      pdfauthor  = {\icai@authorinpdfmetadata},
      pdfsubject = {Proceedings of the ICAI 2023},
    }}
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% MAKE TITLE
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\maketitle{
  \icai@saveinfos
  \ificai@manuscript\else\icai@copyright\fi
  \thispagestyle{icai@titlepagestyle}
  \pagestyle{icai@pagestyle}
  \vspace*{25mm}
  \begingroup
    \centering
    \normalfont\normalsize
    {\LARGE\bfseries\icai@title\\}\vskip8mm
    {\large\bfseries\icai@author\\}\vskip5mm
    {\small\rmfamily\icai@institute\\}\vskip8mm
    \ifx\icai@dedicated\empty\else{\itshape\icai@dedicated\\}\vskip8mm\fi
    \par
  \endgroup
  \setcounter{footnote}{0}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% OPTION: VOLUME
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\ificai@volume

\RequirePackage{pdfpages,newpax}
\newpaxsetup{usefileattributes=true}

\AddToHook{begindocument/end}{
  \hypersetup{
    pdftitle={Proceedings of the ICAI 2023},
    pageanchor=false}}

\def\VOLtocline#1#2#3#4{%
  % #1 paper filename (only information)
  % #2 author
  % #3 title
  % #4 page number
  \contentsline{section}{\textsc{#2}, #3}{\hyperpage{#4}}{}}

\def\SECTION#1{\medskip\noindent{\normalfont\bfseries #1}\par\medskip}

\def\tableofcontents{
  \clearpage
  \section*{Contents}
  \babel@toc{english}{}\relax
  \input{pdfcontents.txt}
  \ifodd\value{page}\newpage\mbox{}\fi
  \setcounter{page}{0}
  \hypersetup{pageanchor}}

\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% END
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\endinput